@@ -18,14 +18,18 @@ class RDS():
     #connect
     cn_parser = rds_subparser.add_parser("connect",
         help = "Connect to the primary or replica Mysql server")
-    cn_parser.add_argument("-r", "--replica", dest="replica", 
+    cn_parser.add_argument("-a", "--autocomplete", dest="autocomplete",
+        action = "store_true", help="enable tab-completion of table and column names (with slower startup)")
+    cn_parser.add_argument("-r", "--replica", dest="replica",
         action = "store_true", help="Login into read replica")
     cn_parser.set_defaults(func=self.connect)
-    
+
     #tunnel
     tn_parser = rds_subparser.add_parser("tunnel",
         help = "Connect to the primary or replica Mysql server through a tunnel on a web node")
-    tn_parser.add_argument("-r", "--replica", dest="replica", 
+    tn_parser.add_argument("-a", "--autocomplete", dest="autocomplete",
+        action = "store_true", help="enable tab-completion of table and column names (with slower startup)")
+    tn_parser.add_argument("-r", "--replica", dest="replica",
         action = "store_true", help="Login into read replica")
     tn_parser.set_defaults(func=self.tunnel)
 
@@ -46,9 +50,14 @@ class RDS():
       hostname = creds["rr_host"]
     else:
       hostname = creds["host"]
-    mysql  = check_call(["mysql", "-u", creds["username"],
-        "-p%s" % creds["password"],"-h", hostname]) 
-  
+
+    if args.autocomplete:
+        mysql  = check_call(["mysql", "-u", creds["username"],
+        "-p%s" % creds["password"],"-h", hostname])
+    else:
+        mysql  = check_call(["mysql", "-u", creds["username"],
+        "-p%s" % creds["password"],"-h", hostname, "-A"])
+
   def tunnel(self, args):
     knife = Knife()
     temp = knife.get_pemfile(args.environment)
@@ -59,7 +68,14 @@ class RDS():
       hostname = creds["rr_host"]
     else:
       hostname = creds["host"]
+
     tunnel = SSHTunnel("ec2-user", list[0], hostname, temp, 22, 3306, 33306)
-    mysql  = check_call(["mysql", "-u", creds["username"],
-        "-p%s" % creds["password"],"-h", "127.0.0.1", "-P", "33306"]) 
+
+    if args.autocomplete:
+        mysql  = check_call(["mysql", "-u", creds["username"],
+        "-p%s" % creds["password"],"-h", "127.0.0.1", "-P", "33306"])
+    else:
+        mysql  = check_call(["mysql", "-u", creds["username"],
+        "-p%s" % creds["password"],"-h", "127.0.0.1", "-P", "33306", "-A"])
+
     os.unlink(temp)
